@@ -8,7 +8,7 @@ use CAM::PDF;
 use Getopt::Long;
 use Pod::Usage;
 
-our $VERSION = '1.21';
+our $VERSION = '1.50';
 
 my %opts = (
             template   => 'crunchjpg_tmpl.pdf',
@@ -66,7 +66,7 @@ my $doc = CAM::PDF->new($infile) || die "$CAM::PDF::errstr\n";
 my $pages = $doc->numPages();
 my $nimages = 0;
 my $rimages = 0;
-my %doneobjs = ();
+my %doneobjs;
 
 for my $p (1..$pages)
 {
